@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2013 Roger Light <roger@atchoo.org>
@@ -16,13 +16,18 @@
 # This example shows how you can use the MQTT client in a class.
 
 import context  # Ensures paho is in PYTHONPATH
+
 import paho.mqtt.client as mqtt
 
+
 class MyMQTTClass(mqtt.Client):
 
     def on_connect(self, mqttc, obj, flags, rc):
         print("rc: "+str(rc))
 
+    def on_connect_fail(self, mqttc, obj):
+        print("Connect failed")
+
     def on_message(self, mqttc, obj, msg):
         print(msg.topic+" "+str(msg.qos)+" "+str(msg.payload))
 
@@ -36,7 +41,7 @@ class MyMQTTClass(mqtt.Client):
         print(string)
 
     def run(self):
-        self.connect("mqtt.eclipse.org", 1883, 60)
+        self.connect("mqtt.eclipseprojects.io", 1883, 60)
         self.subscribe("$SYS/#", 0)
 
         rc = 0
