@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a client sends a correct UNSUBSCRIBE packet.
 
@@ -24,14 +24,14 @@ try:
     (conn, address) = sock.accept()
     conn.settimeout(10)
 
-    if paho_test.expect_packet(conn, "connect", connect_packet):
-        conn.send(connack_packet)
+    paho_test.expect_packet(conn, "connect", connect_packet)
+    conn.send(connack_packet)
 
-        if paho_test.expect_packet(conn, "unsubscribe", unsubscribe_packet):
-            conn.send(unsuback_packet)
+    paho_test.expect_packet(conn, "unsubscribe", unsubscribe_packet)
+    conn.send(unsuback_packet)
 
-            if paho_test.expect_packet(conn, "disconnect", disconnect_packet):
-                rc = 0
+    paho_test.expect_packet(conn, "disconnect", disconnect_packet)
+    rc = 0
 
     conn.close()
 finally:
