@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a client sends a correct PUBLISH to a topic with QoS 0.
 # Use paho.mqtt.publish helper for that.
@@ -23,7 +23,7 @@ connect_packet = paho_test.gen_connect(
 connack_packet = paho_test.gen_connack(rc=0)
 
 publish_packet = paho_test.gen_publish(
-    u"pub/qos0/test", qos=0, payload="message".encode('utf-8'),
+    u"pub/qos0/test", qos=0, payload="message"
 )
 
 disconnect_packet = paho_test.gen_disconnect()
@@ -36,12 +36,12 @@ try:
     (conn, address) = sock.accept()
     conn.settimeout(10)
 
-    if paho_test.expect_packet(conn, "connect", connect_packet):
-        conn.send(connack_packet)
+    paho_test.expect_packet(conn, "connect", connect_packet)
+    conn.send(connack_packet)
 
-        if paho_test.expect_packet(conn, "publish", publish_packet):
-            if paho_test.expect_packet(conn, "disconnect", disconnect_packet):
-                rc = 0
+    paho_test.expect_packet(conn, "publish", publish_packet)
+    paho_test.expect_packet(conn, "disconnect", disconnect_packet)
+    rc = 0
 
     conn.close()
 finally:
